pub enum BrowserProvider {
DiscoveredChrome,
ManagedChrome,
ChromeExecutable(PathBuf),
}Expand description
Explicit provider selection for a Browser pool.
Variants
DiscoveredChrome
Use an already installed or previously managed Chrome executable.
ManagedChrome
Permit A3S Use to download Chrome when no executable is available.
ChromeExecutable(PathBuf)
Use this exact Chrome-compatible executable.
Implementations
Sourceimpl BrowserProvider
impl BrowserProvider
pub fn backend(&self) -> BrowserBackend